unit uCmdLineUtils;

interface

uses
  Classes;

function progName : string;
procedure PrintVersion;
procedure PrintUsageError;
procedure setErrorOutputFile(var F : TextFile);
function getIncludePath : string;
procedure WriteCompilerOutput(aStrings : TStrings);
function getFilename : string;

implementation

uses
  SysUtils, ParamUtils, uVersionInfo;

function progName : string;
begin
  Result := ExtractFileName(ParamStr(0));
  Result := ChangeFileExt(Result, '');
end;

procedure PrintVersion;
var
  V : TVersionInfo;
  TFS : TFileStream;
  s, app : string;
begin
  app := ParamStr(0);
  TFS := TFileStream.Create(app, fmOpenRead or fmShareDenyNone);
  try
    s := FormatDateTime('mmm dd yyyy hh:mm:ss',FileDateToDateTime(FileGetDate(TFS.Handle)));
  finally
    TFS.Free;
  end;
  V := GetVersionInfo(app);
  Writeln(V.ProductName + ' version ' + V.ProductVersion + ' (' +  V.FileVersion + ', built ' + s + ')');
  Writeln('     ' + V.LegalCopyright);
end;

procedure PrintUsageError;
begin
  PrintVersion;
  Writeln('Use "' + progName + ' -help" for more information.');
end;

procedure setErrorOutputFile(var F : TextFile);
var
  val, dir : string;
begin
  val := '';
  if ParamSwitch('-E', false) then
  begin
    val := ParamValue('-E', false);
    dir := ExtractFilePath(val);
    if dir <> '' then
      ForceDirectories(dir);
  end;
  AssignFile(F, val);
  Rewrite(F);
end;

function getIncludePath : string;
begin
  Result := ExtractFilePath(ParamStr(0));
  if ParamSwitch('-I', false) then
  begin
    Result := ParamValue('-I', false);
  end;
end;

procedure WriteCompilerOutput(aStrings : TStrings);
var
  dir, logFilename : string;
begin
  if ParamSwitch('-L', False) then
  begin
    logFilename := ParamValue('-L', False);
    dir := ExtractFilePath(logFilename);
    if dir <> '' then
      ForceDirectories(dir);
    // the code listing is the source code (since it is assembler)
    aStrings.SaveToFile(logFilename);
  end;
end;

function getFilename : string;
var
  i : Integer;
  tmp : string;
begin
  Result := '';
  for i := 1 to ParamCount do
  begin
    tmp := ParamStr(i);
    if Pos('-', tmp) = 1 then Continue; // a switch
    if FileExists(tmp) then
    begin
      Result := tmp;
      Break;
    end;
  end;
end;

end.
